import React from 'react';
import { Link, useNavigate } from 'react-router-dom';

const Navbar = () => {
  const menuItems = ['home', 'about', 'board', 'etc'];
  const postCategories = ['developer', 'systemengineer', 'etc'];
  const navigate = useNavigate();

  return (
    <nav className="fixed w-full z-50 bg-white/90 backdrop-blur-md shadow-sm">
      <div className="container mx-auto px-4">
        <div className="flex justify-between items-center h-16">
          <Link to="/" className="text-2xl font-bold text-[#3B82F6]">TechEdu</Link>
          <div className="hidden md:flex items-center space-x-8">
            {menuItems.map((item) => (
              <Link
                key={item}
                to={item === 'home' ? '/' : `/${item}`}
                className="text-gray-600 hover:text-[#D4AF37]"
              >
                {item.charAt(0).toUpperCase() + item.slice(1)}
              </Link>
            ))}

            {/* ▼ Post Dropdown */}
            <div className="relative group">
              <button className="text-gray-600 hover:text-[#D4AF37] flex items-center">
                Post <i className="fas fa-chevron-down ml-1 text-xs"></i>
              </button>
              <div className="absolute hidden group-hover:block bg-white shadow-md mt-2 rounded-md py-2">
                {postCategories.map(category => (
                  <button
                    key={category}
                    onClick={() => navigate(`/post/${category.toLowerCase()}`)}
                    className="block px-4 py-2 text-gray-600 hover:bg-gray-50 hover:text-[#D4AF37] w-full text-left"
                  >
                    {category.charAt(0).toUpperCase() + category.slice(1)}
                  </button>
                ))}
              </div>
            </div>

            {/* ✅ 로그인 버튼 */}
            <Link
              to="/login"
              className="bg-[#3B82F6] text-white px-4 py-2 rounded hover:bg-blue-700 transition"
            >
              로그인
            </Link>
          </div>
        </div>
      </div>
    </nav>
  );
};

export default Navbar;
